@@ -1,4 +1,4 @@
-# Copyright (c) 2025  Joe Clarke <jclarke@cisco.com>
+# Copyright (c) 2025  Cisco Systems, Inc.
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -23,6 +23,7 @@
 # SUCH DAMAGE.
 
 import logging
+from typing import Any
 
 import httpx
 import virl2_client
@@ -78,17 +79,21 @@ class CMLClient(object):
             try:
                 resp = await self.client.get(url)
                 resp.raise_for_status()
+                return  # Already authenticated
             except httpx.HTTPStatusError as e:
                 if e.response.status_code == 401:  # Unauthorized, re-authenticate
                     logger.debug("Authentication failed, re-authenticating")
                     self.token = None
+                else:
+                    logger.error(f"Error checking authentication: {e}", exc_info=True)
+                    raise e
             except httpx.RequestError as e:
                 logger.error(f"Error checking authentication: {e}", exc_info=True)
                 raise e
 
         # If token is None or authentication failed, re-authenticate
         if not self.token:
-            logger.debug("Re-authenticating with CML API")
+            logger.debug("[Re-]authenticating with CML API")
             await self.login()
 
     async def is_admin(self) -> bool:
@@ -98,11 +103,13 @@ class CMLClient(object):
         """
         if self.admin is not None:
             return self.admin
+
+        await self.check_authentication()
         try:
-            resp = await self.client.get(f"/api/v0/users/{self.username}/id")
+            resp = await self.client.get(f"{self.base_url}/api/v0/users/{self.username}/id")
             resp.raise_for_status()
             user_id = resp.json()
-            resp = await self.client.get(f"/api/v0/users/{user_id}")
+            resp = await self.client.get(f"{self.base_url}/api/v0/users/{user_id}")
             resp.raise_for_status()
             self.admin = resp.json().get("admin", False)
             return self.admin
@@ -110,7 +117,7 @@ class CMLClient(object):
             logger.error(f"Error checking admin status: {e}", exc_info=True)
             return False
 
-    async def get(self, endpoint: str, params: dict | None = None) -> dict:
+    async def get(self, endpoint: str, params: dict | None = None) -> Any:
         """
         Make a GET request to the CML API.
         """
@@ -124,7 +131,7 @@ class CMLClient(object):
             logger.error(f"Error making GET request to {url}: {e}", exc_info=True)
             raise e
 
-    async def post(self, endpoint: str, data: dict | None = None) -> dict | None:
+    async def post(self, endpoint: str, data: dict | None = None) -> Any | None:
         """
         Make a POST request to the CML API.
         """
@@ -140,7 +147,7 @@ class CMLClient(object):
             logger.error(f"Error making POST request to {url}: {e}", exc_info=True)
             raise e
 
-    async def put(self, endpoint: str, data: dict | None = None) -> dict | None:
+    async def put(self, endpoint: str, data: dict | None = None) -> Any | None:
         """
         Make a PUT request to the CML API.
         """
@@ -172,7 +179,7 @@ class CMLClient(object):
             logger.error(f"Error making DELETE request to {url}: {e}", exc_info=True)
             raise e
 
-    async def patch(self, endpoint: str, data: dict | None = None) -> dict | None:
+    async def patch(self, endpoint: str, data: dict | None = None) -> Any | None:
         """
         Make a PATCH request to the CML API.
         """
@@ -188,5 +195,5 @@ class CMLClient(object):
             logger.error(f"Error making PATCH request to {url}: {e}", exc_info=True)
             raise e
 
-    async def close(self):
+    async def close(self) -> None:
         await self.client.aclose()
