@@ -68,7 +68,6 @@ class ExternalConnectorBase(BaseModel, extra="allow"):
     )
 
 
-# External connector models will be moved to separate file soon.
 ExternalConnectorLabel = Annotated[Label, Field(description="Unique label for the external connector.")]
 
 
@@ -405,7 +404,7 @@ class DomInfo(NodeCountsBase, extra="forbid"):
 
 class CpuHealthStats(BasicCpuStats, extra="forbid"):
     model: str = Field(..., description="The CPU model name.")
-    hyperthreading: bool = Field(..., description="Indicates if hyperthreading is enabled.")
+    hyperthreading: bool = Field(default=False, description="Indicates if hyperthreading is enabled.")
     predicted: int = Field(..., description="The number of predicted CPUs.", ge=0)
     load: list[float] = Field(..., description="The CPU load (last few entries).")
 
